from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session
from core.database import get_db
from schemas.car import CarCreate, CarSchema
from helpers.car_helpers import create_car, get_car_by_name

router = APIRouter()

@router.post("/cars", status_code=201, response_model=CarSchema)
async def create_new_car(
    car_data: CarCreate,
    db: Session = Depends(get_db)
):
    new_car = create_car(db=db, car_data=car_data)
    return new_car

@router.get("/cars/{name}", status_code=200, response_model=CarSchema)
async def get_car(
    name: str,
    db: Session = Depends(get_db)
):
    car = get_car_by_name(db=db, name=name)
    if not car:
        raise HTTPException(status_code=404, detail="Car not found")
    return car